<template>
  <ProTabs
    v-model="queryState.mineHireType"
    name="home-tab"
    :showPaneContent="false"
    class="home-tabs"
    isTransparent
    title-gutter="12"
    title-scroll
  >
    <ProTabPane :title="`已签约`" :pane-key="FlexWorkerEleSignEnum.HasSign"></ProTabPane>
    <ProTabPane :title="`待签约`" :pane-key="FlexWorkerEleSignEnum.WaitSign"></ProTabPane>
    <ProTabPane :title="`已解约`" :pane-key="FlexWorkerEleSignEnum.CancelSign"></ProTabPane>
  </ProTabs>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
    :key="queryState.mineHireType"
  >
    <template #renderItem="{ item }">
      <FlexJobCard :show-done-detail="false" :show-footer-left="false" @click="goDetail(item)">
        <template #footerRight>
          <template v-if="queryState.mineHireType === FlexWorkerEleSignEnum.HasSign">
            <nut-button
              class="flexJobManage-card-plain-button"
              type="default"
              plain
              @click.stop="handleUnContract"
              >解约</nut-button
            >
            <nut-button type="primary" @click.stop="checkContract">查看合约</nut-button>
          </template>
          <nut-button v-else type="primary" @click.stop="goSignContract(item)">签约</nut-button>
        </template>
      </FlexJobCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { FlexJobCard, ProTabs, ProTabPane } from '@12333/components';
import { RouterPath } from '@/constants';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import { FlexWorkerEleSignEnum } from '@/constants/task';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'InnerPage',
});

const queryState = reactive({
  mineHireType: FlexWorkerEleSignEnum.HasSign,
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexSignWorkerListInput = {
      signStatus: queryState.mineHireType,
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexSignWorkerList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexSignWorkerList', queryState],
  }
);

function goDetail(item: API.GetNewestWorkerListOutput) {
  Taro.navigateTo({
    url: `${RouterPath.flexJobDetailFromManage}?userId=${item.userId}`,
  });
}

function checkContract() {}
function handleUnContract() {}
function goSignContract(item: API.GetNewestWorkerListOutput) {
  Taro.navigateTo({
    url: `${RouterPath.flexJobSign}`,
  });
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.flexJobManage-page-wrapper {
  .flexJobManage-card-plain-button {
    margin-right: 30px;

    &.nut-button--plain {
      border-width: 1px;
    }
  }
}
</style>
